Struct haybale::Location [−][src]
pub struct Location<'p> {
pub module: &'p Module,
pub func: &'p Function,
pub bb: &'p BasicBlock,
pub instr: BBInstrIndex,
pub source_loc: Option<&'p DebugLoc>,
}Expand description
Fully describes a code location within the LLVM IR.
Fields
module: &'p Modulefunc: &'p Functionbb: &'p BasicBlockinstr: BBInstrIndexsource_loc: Option<&'p DebugLoc>Source location which this IR location corresponds to, if available.
Implementations
Format this Location as a string, including the full module name
Format this Location as a string, omitting the module name
Format this Location as a string, including the short module name. The
short module name is the part of the module name after the last /, if
any; or the full module name, if the module name does not contain a /.